==> 3.2.0.tar.gz: test/operations/oob_payload_decode_test.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:nevis_mobile_authentication_sdk_ios/nevis_mobile_authentication_sdk_ios.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

import '../mocks/method_channel_mock.dart';
import '../mocks/method_channel_test_shared_mocks.mocks.dart';
import '../test_data/common_test_data.dart';
import '../test_data/oob_payload_decode_test_data.dart';
import '../util/ios_test_init.dart';

void main() {
  IosTestInit.initIosTestCase();

  group(NevisMobileAuthenticationSdkIos, () {
    late NevisMobileAuthenticationSdkIos sdk;
    late PlatformOperationCache mockCache;
    late MethodChannelMock channel;

    group("Given oobPayloadDecode is called", () {
      setUp(() {
        sdk = NevisMobileAuthenticationSdkIos();
        mockCache = MockMethodChannelMethodCallCache();
        PlatformOperationCache.instance = mockCache;
        channel = MethodChannelMock(
          method: 'payloadDecode',
          result: CommonTestData.emptyResponse,
        );
      });

      tearDown(() {
        resetMockitoState();
      });

      group("When the json is correct", () {
        test("Then result is success", () async {
          final operation = MockOutOfBandPayloadDecodePlatformOperation();
          when(mockCache.createOperation(any)).thenReturn(operation);

          await sdk.operations.outOfBandPayloadDecode(
            operationId: CommonTestData.operationId,
            json: OobPayloadDecodeTestData.payloadJson,
            base64UrlEncoded: null,
            onSuccess: (payload) {},
            onError: (error) {},
          );

          expect(channel.mappedArgs, OobPayloadDecodeTestData.correctArguments);
          verify(
            mockCache.createOperation(
                argThat(isA<OutOfBandPayloadDecodePlatformOperation>())),
          );
        });
      });
    });
  });
}

==> 3.4.0.tar.gz: test/operations/oob_payload_decode_test.dart <==
// Copyright © 2022 Nevis Security AG. All rights reserved.

import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:nevis_mobile_authentication_sdk_ios/nevis_mobile_authentication_sdk_ios.dart';
import 'package:nevis_mobile_authentication_sdk_platform_interface/nevis_mobile_authentication_sdk_platform_interface.dart';

import '../mocks/method_channel_mock.dart';
import '../mocks/method_channel_test_shared_mocks.mocks.dart';
import '../test_data/common_test_data.dart';
import '../test_data/oob_payload_decode_test_data.dart';
import '../util/ios_test_init.dart';

void main() {
  IosTestInit.initIosTestCase();

  group(NevisMobileAuthenticationSdkIos, () {
    late NevisMobileAuthenticationSdkIos sdk;
    late PlatformOperationCache cache;
    late MethodChannelMock channel;
    const methodName = 'payloadDecode';

    group("Given $methodName is called", () {
      setUp(() {
        sdk = NevisMobileAuthenticationSdkIos();
        cache = MockMethodChannelMethodCallCache();
        PlatformOperationCache.instance = cache;
        channel = MethodChannelMock(
          method: methodName,
          result: CommonTestData.emptyResponse,
        );
      });

      tearDown(() {
        resetMockitoState();
      });

      group("When the json is correct", () {
        test("Then result is success", () async {
          final operation = MockOutOfBandPayloadDecodePlatformOperation();
          when(cache.createOperation(any)).thenReturn(operation);

          await sdk.operations.outOfBandPayloadDecode(
            operationId: CommonTestData.operationId,
            json: OobPayloadDecodeTestData.payloadJson,
            base64UrlEncoded: null,
            onSuccess: (payload) {},
            onError: (error) {},
          );

          expect(
            channel.mappedArgs,
            OobPayloadDecodeTestData.correctArguments,
          );
          verify(
            cache.createOperation(argThat(
              isA<OutOfBandPayloadDecodePlatformOperation>(),
            )),
          );
        });
      });
    });
  });
}
